dropping f15 and moving to f16
authorThierry Parmentelat <thierry.parmentelat@sophia.inria.fr>
Fri, 9 Dec 2011 09:26:12 +0000 (10:26 +0100)
committerThierry Parmentelat <thierry.parmentelat@sophia.inria.fr>
Fri, 9 Dec 2011 09:26:12 +0000 (10:26 +0100)
onelab-k32-tags.mk
pkgs.py
vbuild-init-vserver.sh

index 6fd8d64..e73bcb0 100644 (file)
@@ -4,8 +4,8 @@
 linux-2.6-BRANCH               := rhel6
 linux-2.6-GITPATH               := git://git.onelab.eu/linux-2.6.git@linux-2.6-32-27
 # help out spec2make on f8 and centos5, due to a bug in rpm 
-# ditto on f15 for spec2make.py - tmp hopefully
-ifeq "$(DISTRONAME)" "$(filter $(DISTRONAME),f8 f15 centos5)"
+# ditto on f16 for spec2make.py - tmp hopefully
+ifeq "$(DISTRONAME)" "$(filter $(DISTRONAME),f8 f16 centos5)"
 kernel-WHITELIST-RPMS  := kernel-devel,kernel-headers
 endif
 kernel-DEVEL-RPMS              += elfutils-libelf-devel
diff --git a/pkgs.py b/pkgs.py
index 1f4a7f1..cccd7ea 100755 (executable)
--- a/pkgs.py
+++ b/pkgs.py
@@ -34,7 +34,7 @@ import re
 default_arch='x86_64'
 known_arch = ['i386','x86_64']
 default_fcdistro='f12'
-known_fcdistros = [ 'centos5','centos6','f8', 'f9','f10','f11','f12', 'f13', 'f14', 'f15', 'sl6']
+known_fcdistros = [ 'centos5','centos6','f8', 'f9','f10','f11','f12', 'f13', 'f14', 'f16', 'sl6']
 default_pldistro='onelab'
 
 known_keywords=['groupname', 'groupdesc', 'kexclude', 'package', 'group', 'precious', 'junk', 'mirror', ]
index 3f69cd9..7aed817 100755 (executable)
@@ -171,14 +171,14 @@ function setup_vserver () {
        grep -q ^CAP_SYS_ADMIN $BCAPFILE || echo CAP_SYS_ADMIN >> $BCAPFILE
        grep -q ^CAP_MKNOD $BCAPFILE || echo CAP_MKNOD >> $BCAPFILE
        grep -q ^CAP_IPC_LOCK $BCAPFILE || echo CAP_IPC_LOCK >> $BCAPFILE
# useful for f15 guests that use set_cap_file 
        grep -q ^CAP_SETFCAP $BCAPFILE || echo CAP_SETFCAP >> $BCAPFILE
     else
        ### capabilities required for a myplc vserver
        # for /etc/plc.d/gpg - need to init /dev/random
        grep -q ^CAP_MKNOD $BCAPFILE || echo CAP_MKNOD >> $BCAPFILE
        grep -q ^CAP_NET_BIND_SERVICE $BCAPFILE || echo CAP_NET_BIND_SERVICE >> $BCAPFILE
# useful for f15 guests that use set_cap_file 
        grep -q ^CAP_SETFCAP $BCAPFILE || echo CAP_SETFCAP >> $BCAPFILE
     fi
 
@@ -192,8 +192,8 @@ function setup_vserver () {
     # Enable cgroup
     mkdir /etc/vservers/$vserver/cgroup
 
# Set the init style of your vserver to plain for f15 and higher
# not working with f15 anyways, systemd requires 2.6.36 to work
     case $fcdistro in 
        f1[5-9]) echo plain > /etc/vservers/$vserver/apps/init/style ;;
     esac
@@ -171,14 +171,14 @@ function setup_vserver () {
        grep -q ^CAP_MKNOD $BCAPFILE || echo CAP_MKNOD >> $BCAPFILE
        grep -q ^CAP_IPC_LOCK $BCAPFILE || echo CAP_IPC_LOCK >> $BCAPFILE
-       # useful for f15 guests that use set_cap_file 
+       # useful for f16 guests that use set_cap_file 
        grep -q ^CAP_SETFCAP $BCAPFILE || echo CAP_SETFCAP >> $BCAPFILE
     else
@@ -171,14 +171,14 @@ function setup_vserver () {
        grep -q ^CAP_MKNOD $BCAPFILE || echo CAP_MKNOD >> $BCAPFILE
        grep -q ^CAP_NET_BIND_SERVICE $BCAPFILE || echo CAP_NET_BIND_SERVICE >> $BCAPFILE
-       # useful for f15 guests that use set_cap_file 
+       # useful for f16 guests that use set_cap_file 
        grep -q ^CAP_SETFCAP $BCAPFILE || echo CAP_SETFCAP >> $BCAPFILE
     fi
@@ -192,8 +192,8 @@ function setup_vserver () {
     mkdir /etc/vservers/$vserver/cgroup
 
-    # Set the init style of your vserver to plain for f15 and higher
-    # not working with f15 anyways, systemd requires 2.6.36 to work
+    # Set the init style of your vserver to plain for f16 and higher
+    # not working with f16 anyways, systemd requires 2.6.36 to work
     case $fcdistro in 
        f1[5-9]) echo plain > /etc/vservers/$vserver/apps/init/style ;;